/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.workflow.uad.anonymizer;

import com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.model.WorkflowDefinitionLink;
import com.liferay.portal.kernel.service.WorkflowDefinitionLinkLocalService;
import com.liferay.portal.workflow.uad.constants.PortalWorkflowUADConstants;
import com.liferay.user.associated.data.anonymizer.DynamicQueryUADAnonymizer;

import org.osgi.service.component.annotations.Reference;

/**
 * Provides the base implementation for the workflow definition link UAD anonymizer.
 *
 * <p>
 * This implementation exists only as a container for the default methods
 * generated by ServiceBuilder. All custom service methods should be put in
 * {@link WorkflowDefinitionLinkUADAnonymizer}.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @generated
 */
public abstract class BaseWorkflowDefinitionLinkUADAnonymizer
	extends DynamicQueryUADAnonymizer<WorkflowDefinitionLink> {

	@Override
	public void autoAnonymize(
			WorkflowDefinitionLink workflowDefinitionLink, long userId,
			User anonymousUser)
		throws PortalException {

		if (workflowDefinitionLink.getUserId() == userId) {
			workflowDefinitionLink.setUserId(anonymousUser.getUserId());
			workflowDefinitionLink.setUserName(anonymousUser.getFullName());
		}

		workflowDefinitionLinkLocalService.updateWorkflowDefinitionLink(
			workflowDefinitionLink);
	}

	@Override
	public void delete(WorkflowDefinitionLink workflowDefinitionLink)
		throws PortalException {

		workflowDefinitionLinkLocalService.deleteWorkflowDefinitionLink(
			workflowDefinitionLink);
	}

	@Override
	public Class<WorkflowDefinitionLink> getTypeClass() {
		return WorkflowDefinitionLink.class;
	}

	@Override
	protected ActionableDynamicQuery doGetActionableDynamicQuery() {
		return workflowDefinitionLinkLocalService.getActionableDynamicQuery();
	}

	@Override
	protected String[] doGetUserIdFieldNames() {
		return PortalWorkflowUADConstants.
			USER_ID_FIELD_NAMES_WORKFLOW_DEFINITION_LINK;
	}

	@Reference
	protected WorkflowDefinitionLinkLocalService
		workflowDefinitionLinkLocalService;

}